import { login, loginUp, getInfo } from '@/api/login'
import { getToken, setToken, removeToken, setUserId } from '@/utils/auth'
import { resetRouter } from '@/router'
import { result } from 'lodash'

const getDefaultState = () => {
  return {
    token: getToken(),
    name: '',
    avatar: '',
    UserType: sessionStorage.getItem('UserType') ? sessionStorage.getItem('UserType') : '',
    UserId: sessionStorage.getItem('User_Id') ? sessionStorage.getItem('User_Id') : ''
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_UserId: (state, UserId) => {
    state.UserId = UserId
  },
  SET_UserType: (state, UserType) => {
    state.UserType = UserType
    sessionStorage.setItem('UserType', UserType)
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    return new Promise((resolve, reject) => {
      login(userInfo).then(response => {
        const { returnData } = response
        commit('SET_TOKEN', returnData.Token)
        commit('SET_UserType', returnData.UserType)
        commit('SET_UserId', returnData.UserId)
        sessionStorage.setItem("userName", userInfo.LoginName);
        setToken(returnData.Token)
        setUserId(returnData.UserId)
        let nowDate = new Date();
        let oldDate = new Date(returnData.ValidTime);
        let diffTime = oldDate - nowDate;
        setTimeout(function () {
          resetToken()
        }, diffTime)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // get user info
  getInfo({ commit, state }) {
    return new Promise((resolve, reject) => {

      let data = {
        roles: state.UserType,
        introduction: '',
        avatar: '',
        name: sessionStorage.getItem("userName"),
        token: state.token
      }

      const { name, avatar, roles } = data

      commit('SET_NAME', name)
      commit('SET_AVATAR', avatar)
      commit('SET_ROLES', roles ? roles : ['admin'])
      resolve(data)
    })
  },

  // user logout
  logout({ commit, state }) {
    console.log(state)
    return new Promise((resolve, reject) => {
      loginUp({"UserId":state.UserId,"UserType":state.UserType}).then(result => {
        sessionStorage.removeItem("userName");
        removeToken() // must remove  token  first
        resetRouter()
        commit('RESET_STATE')
        resolve()
      })

      // logout(state.token).then(() => {
      //   removeToken() // must remove  token  first
      //   resetRouter()
      //   commit('RESET_STATE')
      //   resolve()
      // }).catch(error => {
      //   reject(error)
      // })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

